Orange Documentation
====================

Visual programming
------------------

- :doc:`Widget catalog <widgets/rst/index>`

Python Scripting
----------------

- :doc:`Tutorial <tutorial/rst/index>`
- :doc:`Reference <reference/rst/index>`

Development documentation
-------------------------

.. .. - :doc:`Canvas development reference <canvas/index>`

- :doc:`Widget development manual <extend-widgets/rst/index>`
- :doc:`Writing Extensions in C++ <development/rst/c>`
- :doc:`Testing <development/rst/testing>`
- `Wiki pages for developers <http://orange.biolab.si/trac>`_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

